Struct cellular_automaton::Automaton[][src]

pub struct Automaton { /* fields omitted */ }
A two-dimensional cellular automaton with a finite grid of cells.

Implementations

Constructs a new automaton with all cell states set to 0.

Examples

todo!();

Resizes the automaton so that cols is equal to width.

If width is greater than cols, the automaton’s rows are extended by the difference, with each additional column filled with 0. If width is less than cols, the automaton’s rows are simply truncated.

Examples

todo!();

Resizes the automaton so that rows is equal to height.

If height is greater than rows, the automaton’s columns are extended by the difference, with each additional row filled with 0. If height is less than rows, the automaton’s columns are simply truncated.

Examples

todo!();

Returns a raw pointer to the automaton cells’ buffer.

Examples

todo!();

Toggles the state of a cell. If the cell state is 0, it is set to 1. If the cell is any other state, it is set to 0.

Examples

todo!();

Sets the state of cells in locations to 1.

locations is a list of alternating row and column coordinates. This function is implemented with an array as the parameter because wasm_bindgen does not support nested arrays.

Examples

todo!();

Sets the cell state of all the automaton’s cells to n.

Only changes the automaton if n is less than or equal to the generation rule.

Examples

todo!();

Randomizes the cell state of all the automaton’s cells.

Loops through the automaton’s cells and if rand::random() is less than the percentage n, the cell state is set to 1.

Examples

todo!();

Sets all three cell state rules to different values.

Examples

todo!();

Sets the cell survival rule to a different value.

Examples

todo!();

Sets the cell birth rule to a different value.

Examples

todo!();

Sets the cell generation rule to a different value.

Examples

todo!();

Calculates and the state of all cells in the automaton after n generations

Examples

todo!();